REGIONS = {u'ad': u'\u0b85\u0ba3\u0bcd\u0b9f\u0bcb\u0bb0\u0bbe',
 u'ae': u'U.A.E.',
 u'af': u'\u0b86\u0baa\u0bcd\u0b95\u0bbe\u0ba9\u0bbf\u0bb8\u0bcd\u0ba4\u0bbe\u0ba9\u0bcd',
 u'ag': u'\u0b86\u0ba3\u0bcd\u0b9f\u0bbf\u0b95\u0bcd\u0bb5\u0bbe \u0bae\u0bb1\u0bcd\u0bb1\u0bc1\u0bae\u0bcd \u0baa\u0bbe\u0bb0\u0bcd\u0baa\u0bc1\u0b9f\u0bbe',
 u'ai': u'\u0b86\u0b99\u0bcd\u0b95\u0bc1\u0baf\u0bcd\u0bb2\u0bbe',
 u'al': u'\u0b85\u0bb2\u0bcd\u0baa\u0bbe\u0ba9\u0bbf\u0baf\u0bbe',
 u'am': u'\u0b86\u0bb0\u0bcd\u0bae\u0bc7\u0ba9\u0bbf\u0baf\u0bbe',
 u'an': u'\u0ba8\u0bc6\u0ba4\u0bb0\u0bcd\u0bb2\u0bbe\u0ba8\u0bcd\u0ba4\u0bc1 \u0b86\u0ba3\u0bcd\u0b9f\u0bbf\u0bb2\u0bcd\u0bb2\u0bb8\u0bcd',
 u'ao': u'\u0b85\u0ba9\u0bcd\u0b95\u0bcb\u0bb2\u0bbe',
 u'aq': u'\u0b85\u0ba9\u0bcd\u0b9f\u0bbe\u0bb0\u0bcd\u0b9f\u0bbf\u0b95\u0bbe',
 u'ar': u'\u0b85\u0bb0\u0bcd\u0b9c\u0bc6\u0ba3\u0bcd\u0b9f\u0bbe',
 u'as': u'\u0b85\u0bae\u0bc6\u0bb0\u0bbf\u0b95\u0bcd\u0b95\u0ba9\u0bcd \u0b9a\u0bcb\u0bae\u0bcb',
 u'at': u'\u0b86\u0bb8\u0bcd\u0b9f\u0bcd\u0bb0\u0bbf\u0baf\u0bbe',
 u'au': u'\u0b86\u0bb8\u0bcd\u0ba4\u0bbf\u0bb0\u0bc7\u0bb2\u0bbf\u0baf\u0bbe',
 u'aw': u'\u0b85\u0bb0\u0bc2\u0baa\u0bbe',
 u'ax': u'\xc5land \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'az': u'\u0b85\u0b9a\u0bb0\u0bcd\u0baa\u0bc8\u0b9c\u0bbe\u0ba9\u0bcd',
 u'ba': u'\u0baa\u0bcb\u0bb8\u0bcd\u0ba9\u0bbf\u0baf\u0bbe \u0bae\u0bb1\u0bcd\u0bb1\u0bc1\u0bae\u0bcd \u0bb9\u0bc7\u0bb0\u0bcd\u0b9a\u0bbf\u0b95\u0bcb\u0ba9\u0bbf\u0baf\u0bbe',
 u'bb': u'\u0baa\u0bbe\u0bb0\u0bcd\u0baa\u0ba4\u0bbe\u0bb8\u0bcd',
 u'bd': u'\u0bb5\u0b99\u0bcd\u0b95\u0bbe\u0bb3\u0ba4\u0bc7\u0b9a\u0bae\u0bcd',
 u'be': u'\u0baa\u0bc6\u0bb2\u0bcd\u0b9c\u0bbf\u0baf\u0bae\u0bcd',
 u'bf': u'\u0baa\u0bb0\u0bcd\u0b95\u0bbf\u0ba9\u0bbe \u0b83\u0baa\u0bbe\u0b9a\u0bcb',
 u'bg': u'\u0baa\u0bb2\u0bcd\u0b95\u0bc7\u0bb0\u0bbf\u0baf\u0bbe',
 u'bh': u'\u0baa\u0bc6\u0bb9\u0bb0\u0bc8\u0ba9\u0bcd',
 u'bi': u'\u0baa\u0bcd\u0bb0\u0bc2\u0ba3\u0bcd\u0ba4\u0bc0',
 u'bj': u'\u0baa\u0bbf\u0ba9\u0bbf\u0ba9\u0bcd',
 u'bl': u'\u0b9a\u0bc6\u0baf\u0bbf\u0ba3\u0bcd\u0b9f\u0bcd \u0baa\u0bbe\u0bb0\u0bcd\u0ba4\u0bcd\xe9lemy',
 u'bm': u'\u0baa\u0bb0\u0bcd\u0bae\u0bc1\u0b9f\u0bbe',
 u'bn': u'\u0baa\u0bcd\u0bb0\u0bc2\u0ba9\u0bc8 \u0ba4\u0bb0\u0bc1\u0b9a\u0bb2\u0bbe\u0bae\u0bcd',
 u'bo': u'\u0baa\u0bca\u0bb2\u0bbf\u0bb5\u0bbf\u0baf\u0bbe',
 u'br': u'\u0baa\u0bbf\u0bb0\u0bc7\u0b9a\u0bbf\u0bb2\u0bcd',
 u'bs': u'\u0baa\u0bb9\u0bbe\u0bae\u0bbe\u0bb8\u0bcd',
 u'bt': u'\u0baa\u0bc2\u0b9f\u0bbe\u0ba9\u0bcd',
 u'bv': u'\u0baa\u0bcb\u0bb5\u0b9f\u0bcd \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'bw': u'\u0baa\u0bcb\u0b9f\u0bcd\u0bb8\u0bcd\u0bb5\u0bbe\u0ba9\u0bbe',
 u'by': u'\u0baa\u0bc6\u0bb2\u0bbe\u0bb0\u0bb8\u0bcd',
 u'bz': u'\u0baa\u0bbf\u0bb2\u0bc0\u0bb8\u0bcd',
 u'ca': u'\u0b95\u0ba9\u0b9f\u0bbe',
 u'cc': u'\u0b95\u0bcb\u0b95\u0bcb\u0bb8\u0bcd (\u0b95\u0bc0\u0bb2\u0bbf\u0b99\u0bcd) \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'cd': u'\u0b95\u0bbe\u0b99\u0bcd\u0b95\u0bcb-\u0b95\u0bbf\u0ba9\u0bcd\u0bb7\u0bbe\u0b9a\u0bbe',
 u'cf': u'\u0bae\u0ba4\u0bcd\u0ba4\u0bbf\u0baf \u0b86\u0baa\u0bcd\u0baa\u0bbf\u0bb0\u0bbf\u0b95\u0bcd\u0b95 \u0b95\u0bc1\u0b9f\u0bbf\u0baf\u0bb0\u0b9a\u0bc1',
 u'cg': u'\u0b95\u0bbe\u0b99\u0bcd\u0b95\u0bcb-\u0baa\u0bcd\u0bb0\u0bc7\u0b9a\u0bbe\u0bb5\u0bbf\u0bb2\u0bcd\u0bb2\u0bc7',
 u'ch': u'\u0b9a\u0bc1\u0bb5\u0b9f\u0bcd\u0b9a\u0bb0\u0bcd\u0bb2\u0bbe\u0ba8\u0bcd\u0ba4\u0bc1',
 u'ci': u'\u0b90\u0bb5\u0bc7\u0bb0\u0bbf \u0b95\u0b9f\u0bb1\u0bcd\u0b95\u0bb0\u0bc8',
 u'ck': u'\u0b95\u0bc1\u0b95\u0bcd \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'cl': u'\u0b9a\u0bbf\u0bb2\u0bbf',
 u'cm': u'\u0b95\u0bc7\u0bae\u0bcd\u0bb0\u0bc2\u0ba9\u0bcd',
 u'cn': u'\u0b9a\u0bc0\u0ba9\u0bbe',
 u'co': u'\u0b95\u0bca\u0bb2\u0bae\u0bcd\u0baa\u0bbf\u0baf\u0bbe',
 u'cr': u'\u0b95\u0bcb\u0bb8\u0bcd\u0b9f\u0bbe \u0bb0\u0bbf\u0b95\u0bbe',
 u'cu': u'\u0b95\u0bcd\u0baf\u0bc2\u0baa\u0bbe',
 u'cv': u'\u0b95\u0bc7\u0baa\u0bcd \u0bb5\u0bb0\u0bcd\u0b9f\u0bbf',
 u'cx': u'\u0b95\u0bbf\u0bb0\u0bbf\u0bb8\u0bcd\u0bae\u0bb8\u0bcd \u0ba4\u0bc0\u0bb5\u0bc1',
 u'cy': u'\u0b9a\u0bc8\u0baa\u0bcd\u0bb0\u0bb8\u0bcd',
 u'cz': u'\u0b9a\u0bc6\u0b95\u0bcd \u0b95\u0bc1\u0b9f\u0bbf\u0baf\u0bb0\u0b9a\u0bc1',
 u'de': u'\u0b9c\u0bc6\u0bb0\u0bcd\u0bae\u0ba9\u0bbf',
 u'dj': u'\u0b9f\u0bbf\u0b9c\u0bbf\u0baa\u0bcb\u0b9f\u0bbf',
 u'dk': u'\u0b9f\u0bc6\u0ba9\u0bcd\u0bae\u0bbe\u0bb0\u0bcd\u0b95\u0bcd',
 u'dm': u'\u0b9f\u0bcb\u0bae\u0bcd\u0ba9\u0bbf\u0b95\u0bbe',
 u'do': u'\u0b9f\u0bcb\u0bae\u0bcd\u0ba9\u0bbf\u0b95\u0bbe\u0ba9\u0bcd \u0b95\u0bc1\u0b9f\u0bbf\u0baf\u0bb0\u0b9a\u0bc1',
 u'dz': u'\u0b85\u0bb2\u0bcd\u0b95\u0bc7\u0bb0\u0bbf\u0baf\u0bbe',
 u'ec': u'\u0b88\u0b95\u0bc1\u0bb5\u0bc7\u0b9f\u0bbe\u0bb0\u0bcd',
 u'ee': u'\u0b87\u0bb8\u0bcd\u0b9f\u0bcb\u0ba9\u0bbf\u0baf\u0bbe',
 u'eg': u'\u0b8e\u0b95\u0bbf\u0baa\u0bcd\u0ba4\u0bc1',
 u'eh': u'\u0bae\u0bc7\u0bb1\u0bcd\u0b95\u0bc1 \u0b9a\u0b95\u0bbe\u0bb0\u0bbe',
 u'er': u'\u0b8e\u0bb0\u0bbf\u0ba4\u0bcd\u0ba4\u0bbf\u0bb0\u0bbf\u0baf\u0bbe',
 u'es': u'\u0bb8\u0bcd\u0baa\u0bc6\u0baf\u0bbf\u0ba9\u0bcd',
 u'et': u'\u0b8e\u0ba4\u0bcd\u0ba4\u0bbf\u0baf\u0bcb\u0baa\u0bcd\u0baa\u0bbf\u0baf\u0bbe',
 u'fi': u'\u0baa\u0bbf\u0ba9\u0bcd\u0bb2\u0bbe\u0ba8\u0bcd\u0ba4\u0bc1',
 u'fj': u'\u0b83\u0baa\u0bbf\u0b9c\u0bbf',
 u'fk': u'\u0baa\u0bbe\u0b95\u0bcd\u0bb2\u0bbe\u0ba8\u0bcd\u0ba4\u0bc1 \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd (\u0bae\u0bbe\u0bb2\u0bcd\u0bb5\u0bbf\u0ba9\u0bb8\u0bcd)',
 u'fm': u'\u0bae\u0bc8\u0b95\u0bcd\u0bb0\u0bcb\u0ba9\u0bc0\u0bb8\u0bbf\u0baf\u0bbe',
 u'fo': u'\u0b83\u0baa\u0bbe\u0bb0\u0bcb \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'fr': u'\u0baa\u0bbf\u0bb0\u0bbe\u0ba9\u0bcd\u0bb8\u0bcd',
 u'ga': u'\u0b95\u0bbe\u0baa\u0bcb\u0ba9\u0bcd',
 u'gb': u'\u0b90\u0b95\u0bcd\u0b95\u0bbf\u0baf \u0b85\u0bb0\u0b9a\u0bc1',
 u'gd': u'\u0b95\u0bbf\u0bb0\u0bc0\u0ba8\u0bbe\u0b9f\u0bbe',
 u'ge': u'\u0b9c\u0bbe\u0bb0\u0bcd\u0b9c\u0bbf\u0baf\u0bbe',
 u'gf': u'\u0baa\u0bbf\u0bb0\u0b9e\u0bcd\u0b9a\u0bc1 \u0b95\u0bc1\u0baf\u0bcd\u0ba9\u0bbe',
 u'gg': u'\u0b95\u0bc1\u0bb0\u0bcd\u0ba9\u0bcd\u0b9a\u0bc7',
 u'gh': u'\u0b95\u0bbe\u0ba9\u0bbe',
 u'gi': u'\u0b95\u0bbf\u0baa\u0bcd\u0bb0\u0bbe\u0bb2\u0bcd\u0b9f\u0bb0\u0bcd',
 u'gl': u'\u0b95\u0bcd\u0bb0\u0bc0\u0ba9\u0bcd\u0bb2\u0bbe\u0ba8\u0bcd\u0ba4\u0bc1',
 u'gm': u'\u0b95\u0bbe\u0bae\u0bcd\u0baa\u0bbf\u0baf\u0bbe',
 u'gn': u'\u0b95\u0bcd\u0ba9\u0bbf\u0baf\u0bbe',
 u'gp': u'\u0b95\u0bcb\u0b9f\u0bbf\u0bb2\u0bcb\u0baa\u0bcd',
 u'gq': u'\u0bae\u0ba4\u0bcd\u0ba4\u0bbf\u0baf \u0b95\u0bcd\u0ba9\u0bbf\u0baf\u0bbe',
 u'gr': u'\u0b95\u0bcd\u0bb0\u0bc0\u0bb8\u0bcd',
 u'gs': u'\u0ba4\u0bc6\u0ba9\u0bcd \u0b9c\u0bbe\u0bb0\u0bcd\u0b9c\u0bbf\u0baf\u0bbe \u0bae\u0bb1\u0bcd\u0bb1\u0bc1\u0bae\u0bcd \u0ba4\u0bc6\u0ba9\u0bcd \u0b9a\u0bbe\u0ba9\u0bcd\u0bb5\u0bbf\u0b9f\u0bcd\u0b9c\u0bcd \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'gt': u'\u0b95\u0b9f\u0bc7\u0bae\u0bc7\u0bb2\u0bbe',
 u'gu': u'\u0b95\u0baf\u0bc1\u0bae\u0bcd',
 u'gw': u'\u0b95\u0bc8\u0ba9\u0bc7-\u0baa\u0bbf\u0b9a\u0bcb',
 u'gy': u'\u0b95\u0bcd\u0baf\u0bbe\u0ba9\u0bbe',
 u'hk': u'\u0bb9\u0bbe\u0b99\u0bcd \u0b95\u0bbe\u0b99\u0bcd',
 u'hm': u'\u0bb9\u0bbf\u0baf\u0bb0\u0bcd\u0b9f\u0bc1 \u0ba4\u0bc0\u0bb5\u0bc1 \u0bae\u0bb1\u0bcd\u0bb1\u0bc1\u0bae\u0bcd \u0bae\u0bc6\u0b95\u0bcd\u0b9f\u0bcb\u0ba9\u0bbe\u0bb2\u0bcd\u0b9f\u0bc1 \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'hn': u'\u0bb9\u0bbe\u0ba9\u0bcd\u0b9f\u0bc1\u0bb0\u0bc2\u0bb8\u0bcd',
 u'hr': u'\u0b95\u0bc1\u0bb0\u0bc7\u0bb7\u0bbf\u0baf\u0bbe',
 u'ht': u'\u0bb9\u0baf\u0bcd\u0b9f\u0bbf',
 u'hu': u'\u0bb9\u0b99\u0bcd\u0b95\u0bc7\u0bb0\u0bbf',
 u'id': u'\u0b87\u0ba8\u0bcd\u0ba4\u0bcb\u0ba9\u0bc7\u0bb7\u0bbf\u0baf\u0bbe',
 u'ie': u'\u0b85\u0baf\u0bb0\u0bcd\u0bb2\u0bbe\u0ba8\u0bcd\u0ba4\u0bc1',
 u'il': u'\u0b87\u0bb8\u0bcd\u0bb0\u0bc7\u0bb2\u0bcd',
 u'im': u'\u0bb8\u0bcd\u0bb2\u0bc7 \u0b86\u0baa\u0bcd \u0bae\u0bc7\u0ba9\u0bcd',
 u'in': u'\u0b87\u0ba8\u0bcd\u0ba4\u0bbf\u0baf\u0bbe',
 u'io': u'\u0baa\u0bbf\u0bb0\u0bbf\u0b9f\u0bcd\u0b9f\u0bbf\u0bb7\u0bcd \u0b87\u0ba8\u0bcd\u0ba4\u0bbf\u0baf \u0baa\u0bc6\u0bb0\u0bc1\u0b99\u0bcd\u0b95\u0b9f\u0bb2\u0bcd \u0baa\u0bbf\u0bb0\u0ba4\u0bc7\u0b9a\u0bae\u0bcd',
 u'iq': u'\u0b88\u0bb0\u0bbe\u0b95\u0bcd',
 u'ir': u'\u0b88\u0bb0\u0bbe\u0ba9\u0bcd',
 u'is': u'\u0b90\u0bb8\u0bcd\u0bb2\u0bbe\u0ba8\u0bcd\u0ba4\u0bc1',
 u'it': u'\u0b87\u0ba4\u0bcd\u0ba4\u0bbe\u0bb2\u0bbf',
 u'je': u'\u0b9c\u0bc6\u0bb0\u0bcd\u0b9a\u0bbf',
 u'jm': u'\u0b9c\u0bae\u0bbe\u0baf\u0bcd\u0b95\u0bbe',
 u'jo': u'\u0b9c\u0bcb\u0bb0\u0bcd\u0ba4\u0bbe\u0ba9\u0bcd',
 u'jp': u'\u0b9c\u0baa\u0bcd\u0baa\u0bbe\u0ba9\u0bcd',
 u'ke': u'\u0b95\u0bc6\u0ba9\u0bcd\u0baf\u0bbe',
 u'kg': u'\u0b95\u0bc8\u0bb0\u0bcd\u0b9c\u0bbf\u0bb8\u0bcd\u0ba4\u0bbe\u0ba9\u0bcd',
 u'kh': u'\u0b95\u0bae\u0bcd\u0baa\u0bcb\u0b9f\u0bbf\u0baf\u0bbe',
 u'ki': u'\u0b95\u0bbf\u0bb0\u0bbf\u0baa\u0bbe\u0ba4\u0bcd\u0ba4\u0bbf',
 u'km': u'\u0b95\u0bcb\u0bae\u0bcb\u0bb0\u0bcb\u0bb8\u0bcd',
 u'kn': u'\u0b9a\u0bc6\u0baf\u0bbf\u0ba9\u0bcd\u0b9f\u0bcd \u0b95\u0bbf\u0b9f\u0bbf\u0bb8\u0bcd \u0bae\u0bb1\u0bcd\u0bb1\u0bc1\u0bae\u0bcd \u0ba8\u0bc7\u0bb5\u0bbf\u0bb8\u0bcd',
 u'kp': u'\u0bb5\u0b9f\u0b95\u0bcd\u0b95\u0bc1 \u0b95\u0bca\u0bb0\u0bbf\u0baf\u0bbe',
 u'kr': u'\u0ba4\u0bc6\u0bb1\u0bcd\u0b95\u0bc1 \u0b95\u0bca\u0bb0\u0bbf\u0baf\u0bbe',
 u'kw': u'\u0b95\u0bc1\u0bb5\u0bc8\u0ba4\u0bcd',
 u'ky': u'\u0b95\u0bc7\u0bae\u0bc7\u0ba9\u0bcd \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'kz': u'\u0b95\u0bb8\u0b95\u0bcd\u0bb8\u0bcd\u0ba4\u0bbe\u0ba9\u0bcd',
 u'la': u'\u0bb2\u0bcb\u0bb8\u0bcd',
 u'lb': u'\u0bb2\u0bc6\u0baa\u0ba9\u0bbe\u0ba9\u0bcd',
 u'lc': u'\u0b9a\u0bc6\u0baf\u0bbf\u0ba3\u0bcd\u0b9f\u0bcd \u0bb2\u0bc2\u0b9a\u0bbf\u0baf\u0bbe',
 u'li': u'\u0bb2\u0bc8\u0b9a\u0bbf\u0b9f\u0bc6\u0ba9\u0bcd\u0bb8\u0bcd\u0b9f\u0bc0\u0ba9\u0bcd',
 u'lk': u'\u0b87\u0bb2\u0b99\u0bcd\u0b95\u0bc8',
 u'lr': u'\u0bb2\u0bc8\u0baa\u0bc0\u0bb0\u0bbf\u0baf\u0bbe',
 u'ls': u'\u0bb2\u0bbf\u0bb8\u0bcb\u0ba4\u0bcb',
 u'lt': u'\u0bb2\u0bc2\u0ba4\u0bbf\u0baf\u0bbe\u0ba9\u0bbe',
 u'lu': u'\u0bb2\u0bc6\u0b95\u0bcd\u0bb8\u0bae\u0bcd\u0baa\u0bcb\u0bb0\u0bcd\u0b95\u0bcd',
 u'lv': u'\u0bb2\u0b9f\u0bcd\u0bb5\u0bbf\u0baf\u0bbe',
 u'ly': u'\u0bb2\u0bbf\u0baa\u0bbf\u0baf\u0bbe',
 u'ma': u'\u0bae\u0bcb\u0bb0\u0bcb\u0b95\u0bcb',
 u'mc': u'\u0bae\u0bcb\u0ba9\u0bbe\u0b95\u0bcb',
 u'md': u'\u0bae\u0bbe\u0bb2\u0bcd\u0b9f\u0bcb\u0bb5\u0bbe',
 u'me': u'\u0bae\u0bbe\u0ba3\u0bcd\u0b9f\u0bbf\u0ba8\u0b95\u0bb0\u0bcb',
 u'mf': u'\u0b9a\u0bc6\u0baf\u0bbf\u0ba9\u0bcd\u0b9f\u0bcd \u0bae\u0bbe\u0bb0\u0bcd\u0b9f\u0bbf\u0ba9\u0bcd',
 u'mg': u'\u0bae\u0b9f\u0b95\u0bbe\u0bb8\u0bcd\u0b95\u0bb0\u0bcd',
 u'mh': u'\u0bae\u0bbe\u0bb0\u0bcd\u0bb7\u0bb2\u0bcd \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'mk': u'\u0bae\u0bc6\u0b9a\u0bbf\u0b9f\u0bcb\u0ba9\u0bbf\u0baf\u0bbe , F.Y.R.',
 u'ml': u'\u0bae\u0bbe\u0bb2\u0bbf',
 u'mm': u'\u0bae\u0baf\u0ba9\u0bcd\u0bae\u0bbe\u0bb0\u0bcd',
 u'mn': u'\u0bae\u0b99\u0bcd\u0b95\u0bcb\u0bb2\u0bbf\u0baf\u0bbe',
 u'mo': u'\u0bae\u0bbe\u0b95\u0bcb',
 u'mp': u'\u0bb5\u0b9f\u0b95\u0bcd\u0b95\u0bc1 \u0bae\u0bb0\u0bbf\u0baf\u0bbe\u0ba9 \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'mq': u'\u0bae\u0bbe\u0bb0\u0bcd\u0b9f\u0bbf\u0ba9\u0bbf\u0b95\u0bcd\u0baf\u0bc2',
 u'mr': u'\u0bae\u0bcc\u0bb0\u0bbf\u0b9f\u0bbf\u0ba9\u0bbf\u0baf\u0bbe',
 u'ms': u'\u0bae\u0bbe\u0ba3\u0bcd\u0b9f\u0bcd\u0bb8\u0bcd\u0bb0\u0b9f\u0bcd',
 u'mt': u'\u0bae\u0bbe\u0bb2\u0bcd\u0b9f\u0bbe',
 u'mu': u'\u0bae\u0bca\u0bb0\u0bc0\u0bb7\u0bbf\u0baf\u0bb8\u0bcd',
 u'mv': u'\u0bae\u0bbe\u0bb2\u0bcd\u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'mw': u'\u0bae\u0bb2\u0bbe\u0bb5\u0bbf',
 u'mx': u'\u0bae\u0bc6\u0b95\u0bcd\u0bb8\u0bbf\u0b95\u0bcb',
 u'my': u'\u0bae\u0bb2\u0bc7\u0bb7\u0bbf\u0baf\u0bbe',
 u'mz': u'\u0bae\u0bcb\u0bb8\u0bbe\u0bae\u0bcd\u0baa\u0bbf\u0b95\u0bcd',
 u'na': u'\u0ba8\u0bae\u0bc0\u0baa\u0bbf\u0baf\u0bbe',
 u'nc': u'\u0ba8\u0bbf\u0baf\u0bc2 \u0b95\u0bb2\u0bbf\u0b9f\u0bcb\u0ba9\u0bbf\u0baf\u0bbe',
 u'ne': u'\u0ba8\u0bc8\u0b95\u0bb0\u0bcd',
 u'nf': u'\u0ba8\u0bbe\u0bb0\u0bcd\u0baa\u0bcb\u0b95\u0bcd \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'ng': u'\u0ba8\u0bc8\u0b9c\u0bc0\u0bb0\u0bbf\u0baf\u0bbe',
 u'ni': u'\u0ba8\u0bc8\u0b95\u0bb0\u0bbe\u0b95\u0bc1\u0baf\u0bbe',
 u'nl': u'\u0ba8\u0bc6\u0ba4\u0bb0\u0bcd\u0bb2\u0bbe\u0ba8\u0bcd\u0ba4\u0bc1',
 u'no': u'\u0ba8\u0bbe\u0bb0\u0bcd\u0bb5\u0bc7',
 u'np': u'\u0ba8\u0bc7\u0baa\u0bbe\u0bb2\u0bcd',
 u'nr': u'\u0ba8\u0baf\u0bc2\u0bb0\u0bc2',
 u'nu': u'\u0ba8\u0bbf\u0baf\u0bc2',
 u'nz': u'\u0ba8\u0bbf\u0baf\u0bc2\u0bb8\u0bbf\u0bb2\u0bbe\u0ba8\u0bcd\u0ba4\u0bc1',
 u'om': u'\u0b93\u0bae\u0ba9\u0bcd',
 u'pa': u'\u0baa\u0ba9\u0bbe\u0bae\u0bbe',
 u'pe': u'\u0baa\u0bc6\u0bb0\u0bc1',
 u'pf': u'\u0baa\u0bbf\u0bb0\u0b9e\u0bcd\u0b9a\u0bc1 \u0baa\u0bbe\u0bb2\u0bbf\u0ba9\u0bc7\u0bb7\u0bbf\u0baf\u0bbe',
 u'pg': u'\u0baa\u0bbe\u0baa\u0bcd\u0baf\u0bbe \u0baa\u0bc1\u0ba4\u0bbf\u0baf \u0b95\u0bc1\u0ba9\u0bbf\u0baf\u0bbe',
 u'ph': u'\u0baa\u0bbf\u0bb2\u0bbf\u0baa\u0bc8\u0ba9\u0bcd\u0bb8\u0bcd',
 u'pk': u'\u0baa\u0bbe\u0b95\u0bbf\u0bb8\u0bcd\u0ba4\u0bbe\u0ba9\u0bcd',
 u'pl': u'\u0baa\u0bcb\u0bb2\u0ba8\u0bcd\u0ba4\u0bc1',
 u'pm': u'\u0b9a\u0bc6\u0baf\u0bbf\u0ba3\u0bcd\u0b9f\u0bcd \u0baa\u0bc8\u0bb0\u0bc7 \u0bae\u0bb1\u0bcd\u0bb1\u0bc1\u0bae\u0bcd \u0bae\u0bbf\u0b95\u0bcd\u0baf\u0bc1\u0bb2\u0bbe\u0ba9\u0bcd',
 u'pn': u'\u0baa\u0bbf\u0b9f\u0bcd\u0b95\u0bc8\u0bb0\u0ba9\u0bcd',
 u'pr': u'\u0baa\u0bcd\u0baf\u0bc1\u0bb0\u0bcd\u0b9f\u0bcb \u0bb0\u0bbf\u0b95\u0bcb',
 u'ps': u'\u0b86\u0b95\u0bcd\u0b95\u0bbf\u0bb0\u0bae\u0bbf\u0b95\u0bcd\u0b95\u0baa\u0bcd\u0baa\u0b9f\u0bcd\u0b9f \u0baa\u0bbe\u0bb2\u0bb8\u0bcd\u0ba4\u0bc0\u0ba9 \u0baa\u0bbf\u0bb0\u0ba4\u0bc7\u0b9a\u0bae\u0bcd',
 u'pt': u'\u0baa\u0bcb\u0bb0\u0bcd\u0b9a\u0bcd\u0b9a\u0bc1\u0b95\u0bb2\u0bcd',
 u'pw': u'\u0baa\u0bbe\u0bb2\u0bcb',
 u'py': u'\u0baa\u0bb0\u0bbe\u0b95\u0bc1\u0bb5\u0bc7',
 u'qa': u'\u0b95\u0ba4\u0bcd\u0ba4\u0bbe\u0bb0\u0bcd',
 u're': u'\u0bb0\u0bc0\u0baf\u0bc1\u0ba9\u0bbf\u0baf\u0ba9\u0bcd',
 u'ro': u'\u0bb0\u0bcb\u0bae\u0bbe\u0ba9\u0bbf\u0baf\u0bbe',
 u'rs': u'\u0b9a\u0bc6\u0bb0\u0bcd\u0baa\u0bbf\u0baf\u0bbe',
 u'ru': u'\u0bb0\u0bb7\u0bcd\u0baf\u0ba9\u0bcd \u0b85\u0bae\u0bc8\u0baa\u0bcd\u0baa\u0bc1',
 u'rw': u'\u0bb0\u0bc1\u0bb5\u0bbe\u0ba3\u0bcd\u0b9f\u0bbe',
 u'sa': u'\u0b9a\u0bb5\u0bc2\u0ba4\u0bbf \u0b85\u0bb0\u0bc7\u0baa\u0bbf\u0baf\u0bbe',
 u'sb': u'\u0b9a\u0bbe\u0bb2\u0bae\u0bcb\u0ba9\u0bcd \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'sc': u'\u0b9a\u0bc8\u0b9a\u0bbf\u0bb2\u0bb8\u0bcd',
 u'sd': u'\u0b9a\u0bc2\u0b9f\u0bbe\u0ba9\u0bcd',
 u'se': u'\u0b9a\u0bc1\u0bb5\u0bc0\u0b9f\u0ba9\u0bcd',
 u'sg': u'\u0b9a\u0bbf\u0b99\u0bcd\u0b95\u0baa\u0bcd\u0baa\u0bc2\u0bb0\u0bcd',
 u'sh': u'\u0b9a\u0bc6\u0baf\u0bbf\u0ba9\u0bcd\u0b9f\u0bcd \u0bb9\u0bc7\u0bb2\u0bc0\u0ba9\u0bbe',
 u'si': u'\u0bb8\u0bcd\u0bb2\u0bcb\u0bb5\u0bc7\u0ba9\u0bbf\u0baf\u0bbe',
 u'sj': u'\u0b9a\u0bb5\u0bb2\u0bcd\u0baa\u0bbe\u0bb0\u0bcd\u0b9f\u0bcd \u0bae\u0bb1\u0bcd\u0bb1\u0bc1\u0bae\u0bcd \u0b9c\u0ba9\u0bcd \u0bae\u0bbe\u0baf\u0ba9\u0bcd',
 u'sk': u'\u0bb8\u0bcd\u0bb2\u0bcb\u0bb5\u0bbe\u0b95\u0bbf\u0baf\u0bbe',
 u'sl': u'\u0b9a\u0bbf\u0baf\u0bbe\u0bb0\u0bbe \u0bb2\u0bbf\u0baf\u0bcb\u0ba9\u0bcd',
 u'sm': u'\u0b9a\u0bc6\u0ba9\u0bcd \u0bae\u0bb0\u0bbf\u0ba8\u0bcb',
 u'sn': u'\u0bb8\u0bcd\u0ba8\u0bc7\u0b95\u0bb2\u0bcd',
 u'so': u'\u0b9a\u0bcb\u0bae\u0bbe\u0bb2\u0bbf\u0baf\u0bbe',
 u'sr': u'\u0b9a\u0bc1\u0bb0\u0bbf\u0ba8\u0bbe\u0bae\u0bc0',
 u'st': u'\u0b9a\u0bcb \u0b9f\u0bcb\u0bae\u0bcd \u0bae\u0bb1\u0bcd\u0bb1\u0bc1\u0bae\u0bcd \u0baa\u0bcd\u0bb0\u0bbf\u0ba9\u0bcd\u0b9a\u0bbf\u0baa\u0bbf',
 u'sv': u'\u0b8e\u0bb2\u0bcd \u0b9a\u0bb2\u0bcd\u0bb5\u0bc7\u0b9f\u0bb0\u0bcd',
 u'sy': u'\u0b9a\u0bc8\u0bb0\u0bbf\u0baf\u0bbe',
 u'sz': u'\u0b9a\u0bc1\u0bb5\u0bbe\u0bb8\u0bcd\u0bb2\u0bbe\u0ba8\u0bcd\u0ba4\u0bc1',
 u'tc': u'\u0b9f\u0bcd\u0bb0\u0b95\u0bcd\u0bb8\u0bcd \u0bae\u0bb1\u0bcd\u0bb1\u0bc1\u0bae\u0bcd \u0b95\u0bbe\u0baf\u0bcd\u0b95\u0bcb\u0bb8\u0bcd \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'td': u'\u0b9a\u0bbe\u0b9f\u0bcd',
 u'tf': u'\u0baa\u0bbf\u0bb0\u0bc6\u0b9e\u0bcd\u0b9a\u0bc1 \u0ba4\u0bc6\u0ba9\u0bcd \u0baa\u0bbf\u0bb0\u0ba4\u0bc7\u0b9a\u0b99\u0bcd\u0b95\u0bb3\u0bcd',
 u'tg': u'\u0b9f\u0bcb\u0b95\u0bcb',
 u'th': u'\u0ba4\u0bbe\u0baf\u0bcd\u0bb2\u0bbe\u0ba8\u0bcd\u0ba4\u0bc1',
 u'tj': u'\u0ba4\u0b9c\u0bbf\u0b95\u0bbf\u0bb8\u0bcd\u0ba4\u0bbe\u0ba9\u0bcd',
 u'tk': u'\u0b9f\u0bcb\u0b95\u0bbf\u0bb2\u0bcb',
 u'tl': u'\u0ba4\u0bc8\u0bae\u0bc2\u0bb0\u0bcd-\u0bb2\u0bb8\u0bcd\u0b9f\u0bc7',
 u'tm': u'\u0ba4\u0bc1\u0bb0\u0bc1\u0b95\u0bcd\u0bae\u0bc7\u0ba9\u0bbf\u0bb8\u0bcd\u0ba4\u0bbe\u0ba9\u0bcd',
 u'tn': u'\u0ba4\u0bc1\u0ba9\u0bc0\u0bb8\u0bbf\u0baf\u0bbe',
 u'to': u'\u0b9f\u0bcb\u0ba9\u0bcd\u0b95\u0bbe',
 u'tr': u'\u0b9f\u0bb0\u0bcd\u0b95\u0bbf',
 u'tt': u'\u0b9f\u0bcd\u0bb0\u0bc0\u0ba9\u0bbf\u0ba4\u0ba4\u0bcd \u0bae\u0bb1\u0bcd\u0bb1\u0bc1\u0bae\u0bcd \u0b9f\u0bcb\u0baa\u0bbe\u0b95\u0bcb',
 u'tv': u'\u0ba4\u0bc1\u0bb5\u0bbe\u0bb2\u0bc1',
 u'tw': u'\u0ba4\u0bbe\u0baf\u0bcd\u0bb5\u0bbe\u0ba9\u0bcd',
 u'tz': u'\u0ba4\u0bbe\u0ba9\u0bcd\u0b9a\u0bbe\u0ba9\u0bbf\u0baf\u0bbe',
 u'ua': u'\u0b89\u0b95\u0bcd\u0bb0\u0bc6\u0baf\u0bcd\u0ba9\u0bbf',
 u'ug': u'\u0b89\u0b95\u0bbe\u0ba9\u0bcd\u0b9f\u0bbe',
 u'um': u'\u0b90\u0b95\u0bcd\u0b95\u0bbf\u0baf \u0b85\u0bae\u0bc6\u0bb0\u0bbf\u0b95\u0bcd\u0b95 \u0bae\u0bc8\u0ba9\u0bb0\u0bcd \u0b85\u0bb5\u0bc1\u0b9f\u0bcd\u0bb2\u0bc7\u0baf\u0bbf\u0b99\u0bcd \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'us': u'\u0b90\u0b95\u0bcd\u0b95\u0bbf\u0baf \u0b85\u0bae\u0bc6\u0bb0\u0bbf\u0b95\u0bcd\u0b95\u0bbe',
 u'uy': u'\u0b89\u0bb0\u0bc1\u0b95\u0bc1\u0bb5\u0bc7',
 u'uz': u'\u0b89\u0bb8\u0bcd\u0baa\u0bc6\u0b95\u0bbf\u0bb8\u0bcd\u0ba4\u0bbe\u0ba9\u0bcd',
 u'va': u'\u0bb5\u0bbe\u0b9f\u0bbf\u0b95\u0bbe\u0ba9\u0bcd \u0ba8\u0b95\u0bb0\u0bae\u0bcd',
 u'vc': u'\u0b9a\u0bc6\u0baf\u0bbf\u0ba3\u0bcd\u0b9f\u0bcd \u0bb5\u0bbf\u0ba9\u0bcd\u0b9a\u0bc6\u0ba9\u0bcd\u0b9f\u0bcd \u0bae\u0bb1\u0bcd\u0bb1\u0bc1\u0bae\u0bcd \u0b95\u0bcd\u0bb0\u0bc0\u0ba9\u0b9f\u0bbf\u0ba9\u0bcd\u0bb8\u0bcd',
 u've': u'\u0bb5\u0bc6\u0ba9\u0bbf\u0b9a\u0bc2\u0bb2\u0bbe',
 u'vg': u'\u0baa\u0bbf\u0bb0\u0bbf\u0b9f\u0bcd\u0b9f\u0bbf\u0bb7\u0bcd \u0bb5\u0bc6\u0bb0\u0bcd\u0b9c\u0bbf\u0ba9\u0bcd \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'vi': u'U.S. \u0bb5\u0bc6\u0bb0\u0bcd\u0b9c\u0bbf\u0ba9\u0bcd \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
 u'vn': u'\u0bb5\u0bbf\u0baf\u0b9f\u0bcd\u0ba8\u0bbe\u0bae\u0bcd',
 u'vu': u'\u0bb5\u0bc7\u0ba9\u0bcb\u0b9f\u0bcd\u0b9f\u0bc1',
 u'wf': u'\u0bb5\u0bbe\u0bb2\u0bbf\u0bb8\u0bcd \u0bae\u0bb1\u0bcd\u0bb1\u0bc1\u0bae\u0bcd \u0b83\u0baa\u0bc2\u0b9f\u0bcd\u0b9f\u0bc1\u0ba9\u0bbe',
 u'ws': u'\u0bb8\u0bbe\u0bae\u0bcb',
 u'ye': u'\u0b8f\u0bae\u0ba9\u0bcd',
 u'yt': u'\u0bae\u0baf\u0bcb\u0b9f\u0bc0',
 u'za': u'\u0ba4\u0bc6\u0bb1\u0bcd\u0b95\u0bc1 \u0b86\u0b83\u0baa\u0bcd\u0bb0\u0bbf\u0b95\u0bbe',
 u'zm': u'\u0bb8\u0bbe\u0bae\u0bcd\u0baa\u0bbf\u0baf\u0bbe',
 u'zw': u'\u0b9c\u0bbf\u0bae\u0bcd\u0baa\u0bbe\u0baa\u0bcd\u0bb5\u0bc7'}